Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PackageAndSendReplyJSON ¶
PackageAndSendReplyJSON will package the reply and send it over nats
func PackageAndSendReplyString ¶
func PackageAndSendReplyString(repstring ReplyString, NC *nats.Conn, subj string) error
PackageAndSendReplyString will package a ReplyString and send it over nats
Types ¶
type ReplyString ¶
ReplyString will return a reply status with a success boolean and a message attached
func ConstructNegativeReplyString ¶
func ConstructNegativeReplyString(mess string) ReplyString
ConstructNegativeReplyString will create a replyString object with a failed status
func NewReplyStringFromMSG ¶
func NewReplyStringFromMSG(msg *nats.Msg) (ReplyString, error)
NewReplyStringFromMSG will take a nats msg and attempt to turn it into a ReplyString
Click to show internal directories.
Click to hide internal directories.