Documentation
¶
Index ¶
- type NatsFile
- func (nf *NatsFile) NotifyDone()
- func (nf *NatsFile) PackageResponse(success bool, message string, subject string)
- func (nf *NatsFile) ProgressUpdate(file *FS.File, currentLine uint64, readBytes uint64)
- func (nf *NatsFile) RequestLines(msg *nats.Msg)
- func (nf *NatsFile) SendStatus(status string)
- func (nf *NatsFile) SubscribeSubjects() error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NatsFile ¶
type NatsFile struct {
NC *nats.Conn
FileManager *FM.FileManager
FileStreamer *FileStreamer.FileStreamer
RNode *PS.RegisteredNode
// contains filtered or unexported fields
}
NatsFile will broadcast file system services to the NATS server.
func NewNatsFile ¶
NewNatsFile Use this function to create a new NatsFile Object.
func (*NatsFile) NotifyDone ¶
func (nf *NatsFile) NotifyDone()
NotifyDone will request a Done Status be applied to the server
func (*NatsFile) PackageResponse ¶
PackageResponse will respond to the subject with a positive message
func (*NatsFile) ProgressUpdate ¶
ProgressUpdate is part of the adapter to send to the File Streamer
func (*NatsFile) RequestLines ¶
RequestLines will return the requested amount of lines over NATS
func (*NatsFile) SendStatus ¶
SendStatus will fire a status event to the play status
func (*NatsFile) SubscribeSubjects ¶
SubscribeSubjects will subscribe NatsFile to different NATS Subjects
Click to show internal directories.
Click to hide internal directories.